@@ -1469,9 +1469,17 @@ public:
      * Fill a list with the unique names of all fields
      * @param names List to which key names must be added
      * @param list List of parameters whose names to be added
+     * @param checkDupl True to ignore duplicates from the given list
      * @param skip Parameters starting with this prefix will not be added
      */
-    static void fillFieldNames(ObjList& names, const NamedList& list, const char* skip = 0);
+    static void fillFieldNames(ObjList& names, const NamedList& list, bool checkDupl = true, const char* skip = 0);
+
+    /**
+     * Fill a list with the unique names from a Hash list
+     * @param names List to which key names must be added
+     * @param list Hash list whose names are to be added
+     */
+    static void fillFieldNames(ObjList& names, const HashList& list);
 
     /**
      * Try to evaluate a single function in the context
@@ -1509,6 +1517,13 @@ public:
      */
     virtual bool copyFields(ObjList& stack, const ScriptContext& original, GenObject* context);
 
+    /**
+     * Add string parameters from list
+     * @param list Parameters list
+     * @param skipPrefix Skip parameters whose name start with specified prefix
+     */
+    virtual void addFields(const NamedList& list, const char* skipPrefix = "__");
+
     /**
      * Try to evaluate a single field searching for a matching context
      * @param stack Evaluation stack in use, field value must be pushed on it
@@ -2050,6 +2065,13 @@ public:
      */
     virtual ExpOperation* popValue(ObjList& stack, GenObject* context = 0);
 
+    /**
+     * Delete a field of the object
+     * @param name Name of field to remove
+     */
+    virtual void clearField(const String& name)
+	{ params().clearParam(name); }
+
     /**
      * Retrieve the object frozen status (cannot modify attributes or methods)
      * @return True if the object is frozen
@@ -2144,6 +2166,14 @@ public:
      */
     static void printRecursive(const GenObject* obj);
 
+    /**
+     * Static method to obtain a JSON representation of the given object
+     * @param oper Object to represent in JSON format
+     * @param spaces Number of spaces used for one indentation level
+     * @return String represention of the object
+     */
+    static ExpOperation* toJSON(const ExpOperation* oper, int spaces);
+
 protected:
     /**
      * Try to evaluate a single native method
@@ -2162,6 +2192,22 @@ protected:
     inline Mutex* mutex() const
 	{ return m_mutex; }
 
+    /**
+     * Static method to obtain a JSON representation of the given object
+     * @param ns Object to represent in JSON format
+     * @param buf String used as output for the JSON represantion
+     * @param spaces Number of spaces used for one indentation level
+     * @param indent Current number of spaces used for indentation
+     */
+    static void toJSON(const NamedString* ns, String& buf, int spaces, int indent = 0);    
+
+    /**
+     * Static helper method for escaping special characters when JSON stringifying
+     * @param str String to escape
+     * @return Escaped string
+     */
+    static String strEscape(const char* str);
+
 private:
     static const String s_protoName;
     bool m_frozen;
@@ -2656,6 +2702,61 @@ public:
      */
     static bool isUndefined(const ExpOperation& oper);
 
+    /**
+     * Check if an operation is null or undefined
+     * @return True if the operation holds an undefined value or a null object
+     */
+    static bool isMissing(const ExpOperation& oper);
+
+    /**
+     * Check if an operation is missing, holds a null or undefined
+     * @return True if the operation is null or holds an undefined value or a null object
+     */
+    inline static bool isMissing(const ExpOperation* oper)
+	{ return !oper || isMissing(*oper); }
+
+    /**
+     * Check if an operation is not null or undefined
+     * @return True if the operation holds a value or non-null object
+     */
+    inline static bool isPresent(const ExpOperation& oper)
+	{ return !isMissing(oper); }
+
+    /**
+     * Check if an operation is present and not null or undefined
+     * @return True if the operation holds a value or non-null object
+     */
+    inline static bool isPresent(const ExpOperation* oper)
+	{ return oper && !isMissing(*oper); }
+
+    /**
+     * Check if an operation holds a null or undefined value or empty string
+     * @return True if the operation is an undefined value or a null object or empty string
+     */
+    inline static bool isEmpty(const ExpOperation& oper)
+	{ return oper.null() || isMissing(oper); }
+
+    /**
+     * Check if an operation is missing, holds a null or undefined value or empty string
+     * @return True if the operation is an undefined value or a null object or empty string
+     */
+    inline static bool isEmpty(const ExpOperation* oper)
+	{ return TelEngine::null(oper) || isMissing(*oper); }
+
+    /**
+     * Check if an operation is not null or undefined or empty string
+     * @return True if the operation holds a non-empty value or non-null object
+     */
+    inline static bool isFilled(const ExpOperation& oper)
+	{ return oper && !isMissing(oper); }
+
+    /**
+     * Check if an operation is not null or undefined or empty string
+     * @return True if the operation holds a non-empty value or non-null object
+     */
+    inline static bool isFilled(const ExpOperation* oper)
+	{ return !isEmpty(oper); }
+
 private:
     String m_basePath;
     String m_includePath;
